<?php

declare(strict_types=1);

namespace Drupal\micronode\Plugin\views\filter;

use Drupal\views\Plugin\views\filter\BooleanOperator;
use Drupal\views\Views;

/**
 * Detects whether a node is micro-content.
 *
 * @ingroup views_filter_handlers
 *
 * @ViewsFilter("micronode_is_microcontent")
 */
class MicronodeIsMicrocontent extends BooleanOperator {

  /**
   * {@inheritdoc}
   */
  public function query() {
    $this->ensureMyTable();
    $type = "$this->tableAlias.$this->realField";
    // Create a join with the config table.
    $configuration = [
      'table' => 'config',
      'field' => 'name',
      'left_table' => 'node',
      'left_formula' => "CONCAT('node.type.', $type)",
      'operator' => '=',
    ];
    /** @var \Drupal\views\Plugin\views\join\JoinPluginBase $join */
    $join = Views::pluginManager('join')->createInstance('standard', $configuration);
    $this->query->addRelationship('config', $join, 'node');
    $needle = '%{s:25:"micronode\_is\_microcontent";_:' . (int) $this->value . ';}%';
    $this->query->addWhere($this->options['group'], 'config.data', $needle, 'LIKE');
  }

}
